summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--jstests/concurrency/fsm_workload_helpers/server_types.js4
-rw-r--r--jstests/multiVersion/mixed_storage_version_replication.js2
-rw-r--r--jstests/multiVersion/transitioning_to_and_from_WT.js20
-rw-r--r--jstests/noPassthrough/dir_per_db_and_split.js3
-rw-r--r--jstests/noPassthrough/split_collections_and_indexes.js3
-rw-r--r--src/mongo/db/storage/wiredtiger/wiredtiger_init.cpp6
6 files changed, 15 insertions, 23 deletions
diff --git a/jstests/concurrency/fsm_workload_helpers/server_types.js b/jstests/concurrency/fsm_workload_helpers/server_types.js
index 7793adb6381..cb95641955b 100644
--- a/jstests/concurrency/fsm_workload_helpers/server_types.js
+++ b/jstests/concurrency/fsm_workload_helpers/server_types.js
@@ -60,7 +60,7 @@ function isMMAPv1(dbOrServerStatus) {
/**
* Returns true if the current storage engine is wiredTiger
- * (or wiredtiger), and false otherwise.
+ * and false otherwise.
*
* 'dbOrServerStatus' must refer to a mongod connection
* (and not a mongos connection), or the result of the
@@ -79,5 +79,5 @@ function isWiredTiger(dbOrServerStatus) {
assert.neq('undefined', typeof status.storageEngine,
'missing storage engine info in server status');
- return Array.contains(['wiredTiger', 'wiredtiger'], status.storageEngine.name);
+ return Array.contains(['wiredTiger'], status.storageEngine.name);
}
diff --git a/jstests/multiVersion/mixed_storage_version_replication.js b/jstests/multiVersion/mixed_storage_version_replication.js
index 980aa88018e..601aa48388f 100644
--- a/jstests/multiVersion/mixed_storage_version_replication.js
+++ b/jstests/multiVersion/mixed_storage_version_replication.js
@@ -515,7 +515,7 @@ function doMultiThreadedWork(primary, numThreads) {
var oldVersion = "2.6";
var newVersion = "latest";
var setups = [{binVersion: newVersion, storageEngine: 'mmapv1'},
- {binVersion: newVersion, storageEngine: 'wiredtiger'},
+ {binVersion: newVersion, storageEngine: 'wiredTiger'},
{binVersion: oldVersion}
];
var nodes = {};
diff --git a/jstests/noPassthrough/dir_per_db_and_split.js b/jstests/noPassthrough/dir_per_db_and_split.js
index bcd393bfdbe..e03ad7e6746 100644
--- a/jstests/noPassthrough/dir_per_db_and_split.js
+++ b/jstests/noPassthrough/dir_per_db_and_split.js
@@ -1,6 +1,5 @@
-if ( jsTest.options().storageEngine &&
- jsTest.options().storageEngine.toLowerCase() == "wiredtiger" ) {
+if ( jsTest.options().storageEngine == "wiredTiger" ) {
var baseDir = "jstests_per_db_and_split_c_and_i";
port = allocatePorts( 1 )[ 0 ];
diff --git a/jstests/noPassthrough/split_collections_and_indexes.js b/jstests/noPassthrough/split_collections_and_indexes.js
index f3565ef5e77..41916d6e9a0 100644
--- a/jstests/noPassthrough/split_collections_and_indexes.js
+++ b/jstests/noPassthrough/split_collections_and_indexes.js
@@ -1,6 +1,5 @@
-if ( jsTest.options().storageEngine &&
- jsTest.options().storageEngine.toLowerCase() == "wiredtiger" ) {
+if ( jsTest.options().storageEngine == "wiredTiger" ) {
var baseDir = "jstests_split_c_and_i";
port = allocatePorts( 1 )[ 0 ];
diff --git a/src/mongo/db/storage/wiredtiger/wiredtiger_init.cpp b/src/mongo/db/storage/wiredtiger/wiredtiger_init.cpp
index 384413eb6b9..ec8b05b47fd 100644
--- a/src/mongo/db/storage/wiredtiger/wiredtiger_init.cpp
+++ b/src/mongo/db/storage/wiredtiger/wiredtiger_init.cpp
@@ -121,15 +121,9 @@ namespace mongo {
("SetGlobalEnvironment"))
(InitializerContext* context ) {
- // XXX: These cannot be the same WiredTigerFactory instance because
- // some environments delete each registered factory separately.
getGlobalEnvironment()->registerStorageEngine(kWiredTigerEngineName,
new WiredTigerFactory());
- // Allow --storageEngine=wiredtiger to be specified on the command line
- // (for backwards compatibility).
- getGlobalEnvironment()->registerStorageEngine("wiredtiger", new WiredTigerFactory());
-
return Status::OK();
}
diff --git a/jstests/multiVersion/transitioning_to_and_from_WT.js b/jstests/multiVersion/transitioning_to_and_from_WT.js
index 63b29a16e4e..76d0a4df522 100644
--- a/jstests/multiVersion/transitioning_to_and_from_WT.js
+++ b/jstests/multiVersion/transitioning_to_and_from_WT.js
@@ -1,10 +1,10 @@
// Test dump/restore upgrade/downgrade/transition process for:
-// 2.6 -> 2.8 wiredtiger
-// 2.8 wiredtiger -> 2.6
+// 2.6 -> 2.8 wiredTiger
+// 2.8 wiredTiger -> 2.6
// 2.6 -> 2.8
// 2.8 -> 2.8 wiredtiger
// 2.8 wiredtiger -> 2.8
// then back to 2.6 and rerun each transition with directoryperdb on all non-wiredtiger instances
(function() {
@@ -55,13 +55,13 @@
// between in the order they will be used
// version is either "2.6" or null which indicates latest
// storageEngine is either "wiredtiger" or null which indicates mmapv1
// directoryperdb is either "" which indicates it will be used or null which indicates it won't
var modes = [
// to 2.8 wired tiger
{
version: null,
- storageEngine: "wiredtiger",
+ storageEngine: "wiredTiger",
directoryperdb: null,
},
// back to 2.6
@@ -79,7 +79,7 @@
// to 2.8 wired tiger
{
version: null,
- storageEngine: "wiredtiger",
+ storageEngine: "wiredTiger",
directoryperdb: null,
},
// back to 2.8 mmapv1
@@ -97,7 +97,7 @@
// to 2.8 wired tiger
{
version: null,
- storageEngine: "wiredtiger",
+ storageEngine: "wiredTiger",
directoryperdb: null,
},
// back to 2.6 dir per db
@@ -115,7 +115,7 @@
// to 2.8 wired tiger
{
version: null,
- storageEngine: "wiredtiger",
+ storageEngine: "wiredTiger",
directoryperdb: null,
},
// back to 2.8 mmapv1 dir per db
@@ -1,10 +1,10 @@
// 2.6 -> 2.8
-// 2.8 -> 2.8 wiredtiger
-// 2.8 wiredtiger -> 2.8
-// then back to 2.6 and rerun each transition with directoryperdb on all non-wiredtiger instances
+// 2.8 -> 2.8 wiredTiger
+// 2.8 wiredTiger -> 2.8
+// then back to 2.6 and rerun each transition with directoryperdb on all non-wiredTiger instances
(function() {
@@ -55,13 +55,13 @@
// between in the order they will be used
// version is either "2.6" or null which indicates latest
- // storageEngine is either "wiredtiger" or null which indicates mmapv1
+ // storageEngine is either "wiredTiger" or null which indicates mmapv1
// directoryperdb is either "" which indicates it will be used or null which indicates it won't
var modes = [